Dictionary and Tuple Practice
=====================================

.. selectquestion:: two-list-selq
   :ab: dictTupP
   :fromid: dp_two_list_to_dict_pp, dp_two_list_to_dict
   :points: 1

.. selectquestion:: tup-to-dict-selq
   :ab: dictTupP
   :fromid: dp_list_of_tuples_to_dict, dp_list_of_tuples_to_dict_pp
   :points: 1

.. selectquestion:: tup-from-dict-selq
   :ab: dictTupP
   :fromid: dp_get_tuple_from_dict_pp, dp_get_tuple_from_dict
   :points: 1

.. selectquestion:: dict-cutoff-selq
   :ab: dictTupP
   :fromid: dp_greater_dict, dp_greater_dict_pp
   :points: 1

.. selectquestion:: str-count-selq
   :ab: dictTupP
   :fromid: dp_get_counts_dict_pp, dp_get_counts_dict
   :points: 1
